@@ -18,12 +18,13 @@
 from xivo_ws.client.http import HTTPClient
 from xivo_ws.client.webservice import WebServiceClient
 from xivo_ws.registry import get_registered_ws_class
+from xivo_ws.debug.client.http import DebugHTTPClientDecorator
 
 
 class BaseXivoServer(object):
     def __init__(self, ws_client):
         self.ws_client = ws_client
-        for name, ws_class  in get_registered_ws_class().iteritems():
+        for name, ws_class in get_registered_ws_class().iteritems():
             ws = ws_class(ws_client)
             setattr(self, name, ws)
 
@@ -39,3 +40,14 @@ class XivoServer(BaseXivoServer):
 
     def check_ws(self):
         return self.ws_client.check_ws()
+
+
+class DebugXivoServer(BaseXivoServer):
+    def __init__(self, host, username=None, password=None):
+        BaseXivoServer.__init__(self, self._new_ws_client(host, username, password))
+
+    def _new_ws_client(self, host, username, password):
+        http_client = HTTPClient(host, username, password)
+        http_client = DebugHTTPClientDecorator(http_client)
+        ws_client = WebServiceClient(http_client)
+        return ws_client
